@@ -154,6 +154,7 @@ class Anonymiser:
         )
         if text:
             self._print_output(text, target_dataset[0])
+            return target_dataset[0]
 
         else:
             self.dataset_processor.save_dataset_file(
@@ -163,11 +164,21 @@ class Anonymiser:
                 output_dir=self.output_dir,
             )
 
-    def anonymise(self, text: str = None, dataset: str = None) -> None:
-        self.logger.info(
-            "Anonymising text data. n.b 'anonymise' method overwrites the text column."
-        )
-        self._run(text=text, dataset=dataset, replace=True)
+    def anonymise(self, text: str = None, dataset: str = None) -> str | None:
+        """
+        Anonymises text data.
+
+        n.b 'anonymise' method overwrites the text column if a dataset is provided.
+        If only text is provided, the anonymised text is returned.
+        """
+        if text is not None:
+            return self._run(text=text, dataset=dataset, replace=True)
+        elif dataset is not None:
+            self._run(text=None, dataset=dataset, replace=True)
+            return None  # Explicitly return None when operating on the dataset
+        else:
+            self.logger.warning("No text or dataset provided for anonymisation.")
+            return None
 
     def predict(
         self,
